pysjobs — pysjobs v0.1 documentation

### Navigation

- pysjobs v0.1 documentation »

# pysjobs

A framework for running tasks defined in a config file. You can also install the in-development version of pysjobs with `easy_install pysjobs==dev`.

The home page is currently the bitbucket repository.

## Questions & Comments

Please visit: http://groups.google.com/group/pyslibs

## Config File Example

## Usage

## Thanks

To the pip project <http://pypi.python.org/pypi/pip> for a lot of the boiler plate code to get the package up and running and for testing ideas.

### Navigation

- pysjobs v0.1 documentation »